[llvm-commits] CVS: llvm/include/Support/Alloca.h BitSetVector.h CommandLine.h DataTypes.h DepthFirstIterator.h EquivalenceClasses.h GraphTraits.h HashExtras.h LeakDetector.h MathExtras.h NonCopyable.h PostOrderIterator.h STLExtras.h SetOperations.h StringExtras.h TarjanSCCIterator.h Timer.h Tree.h TypeInfo.h hash_map hash_set ilist iterator slist

John Criswell criswell at choi.cs.uiuc.edu
Thu Jun 26 16:40:36 PDT 2003


Changes in directory llvm/include/Support:

Alloca.h added (r1.2.2.1)
BitSetVector.h updated: 1.5.2.1 -> 1.5.2.2
CommandLine.h updated: 1.12.2.1 -> 1.12.2.2
DataTypes.h updated: 1.8.2.1 -> 1.8.2.2
DepthFirstIterator.h updated: 1.4 -> 1.4.2.1
EquivalenceClasses.h updated: 1.2 -> 1.2.2.1
GraphTraits.h updated: 1.2 -> 1.2.2.1
HashExtras.h updated: 1.5 -> 1.5.2.1
LeakDetector.h updated: 1.1 -> 1.1.2.1
MathExtras.h updated: 1.5 -> 1.5.2.1
NonCopyable.h updated: 1.2 -> 1.2.2.1
PostOrderIterator.h updated: 1.8 -> 1.8.2.1
STLExtras.h updated: 1.5 -> 1.5.2.1
SetOperations.h updated: 1.1 -> 1.1.2.1
StringExtras.h updated: 1.3 -> 1.3.2.1
TarjanSCCIterator.h updated: 1.5.2.1 -> 1.5.2.2
Timer.h updated: 1.6.2.1 -> 1.6.2.2
Tree.h updated: 1.3.2.1 -> 1.3.2.2
TypeInfo.h updated: 1.1 -> 1.1.2.1
hash_map updated: 1.6.2.1 -> 1.6.2.2
hash_set updated: 1.6.2.1 -> 1.6.2.2
ilist updated: 1.6.2.1 -> 1.6.2.2
iterator updated: 1.2.2.1 -> 1.2.2.2
slist updated: 1.2.2.1 -> 1.2.2.2

---
Log message:

Merged with mainline on Thursday, June 26, 2003.
Kept includes of "Config/assert.h" to avoid implicit dependencies on header
files.


---
Diffs of the changes:

Index: llvm/include/Support/Alloca.h
diff -c /dev/null llvm/include/Support/Alloca.h:1.1
*** /dev/null	Thu Jun 26 16:37:43 2003
--- llvm/include/Support/Alloca.h	Mon Jun 16 16:53:55 2003
***************
*** 0 ****
--- 1,30 ----
+ //===-- include/Support/Alloca.h - Support for alloca header -----*- C++ -*--=//
+ //
+ // Some platforms do not have alloca.h; others do. You can include this
+ // file instead of <alloca.h> and it will include <alloca.h> on the platforms
+ // that require you to do so to use alloca().
+ //
+ //===----------------------------------------------------------------------===//
+ 
+ #ifndef LLVM_SUPPORT_ALLOCA_H
+ #define LLVM_SUPPORT_ALLOCA_H
+ 
+ // TODO: Determine HAVE_ALLOCA_H based on autoconf results.
+ // The following method is too brittle.
+ #if defined(HAVE_ALLOCA_H)
+ #undef HAVE_ALLOCA_H
+ #endif
+ 
+ #if defined(__linux__)
+ #define HAVE_ALLOCA_H 1
+ #elif defined(__sparc__)
+ #define HAVE_ALLOCA_H 1
+ #elif defined(__FreeBSD__)
+ // not defined here
+ #endif
+ 
+ #if HAVE_ALLOCA_H
+ #include <alloca.h>
+ #endif
+ 
+ #endif  /* LLVM_SUPPORT_ALLOCA_H */


Index: llvm/include/Support/CommandLine.h
diff -u llvm/include/Support/CommandLine.h:1.12.2.1 llvm/include/Support/CommandLine.h:1.12.2.2
--- llvm/include/Support/CommandLine.h:1.12.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/CommandLine.h	Thu Jun 26 16:34:32 2003
@@ -10,8 +10,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_COMMANDLINE_H
-#define LLVM_SUPPORT_COMMANDLINE_H
+#ifndef SUPPORT_COMMANDLINE_H
+#define SUPPORT_COMMANDLINE_H
 
 #include <string>
 #include <vector>


Index: llvm/include/Support/DataTypes.h
diff -u llvm/include/Support/DataTypes.h:1.8.2.1 llvm/include/Support/DataTypes.h:1.8.2.2
--- llvm/include/Support/DataTypes.h:1.8.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/DataTypes.h	Thu Jun 26 16:34:33 2003
@@ -16,8 +16,8 @@
 // TODO: This file sucks.  Not only does it not work, but this stuff should be
 // autoconfiscated anyways. Major FIXME
 
-#ifndef LLVM_SUPPORT_DATATYPES_H
-#define LLVM_SUPPORT_DATATYPES_H
+#ifndef SUPPORT_DATATYPES_H
+#define SUPPORT_DATATYPES_H
 
 //
 // Un-define these constants so that we can re-define only the one that we want
@@ -44,4 +44,4 @@
 #error "include/Support/DataTypes.h could not determine endianness!"
 #endif
 
-#endif  /* LLVM_SUPPORT_DATATYPES_H */
+#endif  /* SUPPORT_DATATYPES_H */


Index: llvm/include/Support/DepthFirstIterator.h
diff -u llvm/include/Support/DepthFirstIterator.h:1.4 llvm/include/Support/DepthFirstIterator.h:1.4.2.1
--- llvm/include/Support/DepthFirstIterator.h:1.4	Sun Oct 27 20:11:16 2002
+++ llvm/include/Support/DepthFirstIterator.h	Thu Jun 26 16:34:33 2003
@@ -5,8 +5,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_DEPTH_FIRST_ITERATOR_H
-#define LLVM_SUPPORT_DEPTH_FIRST_ITERATOR_H
+#ifndef SUPPORT_DEPTHFIRSTITERATOR_H
+#define SUPPORT_DEPTHFIRSTITERATOR_H
 
 #include "Support/GraphTraits.h"
 #include "Support/iterator"


Index: llvm/include/Support/EquivalenceClasses.h
diff -u llvm/include/Support/EquivalenceClasses.h:1.2 llvm/include/Support/EquivalenceClasses.h:1.2.2.1
--- llvm/include/Support/EquivalenceClasses.h:1.2	Wed Jun  4 03:00:05 2003
+++ llvm/include/Support/EquivalenceClasses.h	Thu Jun 26 16:34:33 2003
@@ -8,8 +8,8 @@
 // 
 //===------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_EQUIVALENCE_CLASSES_H
-#define LLVM_SUPPORT_EQUIVALENCE_CLASSES_H
+#ifndef SUPPORT_EQUIVALENCECLASSES_H
+#define SUPPORT_EQUIVALENCECLASSES_H
 
 #include <map>
 #include <vector>


Index: llvm/include/Support/GraphTraits.h
diff -u llvm/include/Support/GraphTraits.h:1.2 llvm/include/Support/GraphTraits.h:1.2.2.1
--- llvm/include/Support/GraphTraits.h:1.2	Sun Oct 13 12:12:05 2002
+++ llvm/include/Support/GraphTraits.h	Thu Jun 26 16:34:33 2003
@@ -8,8 +8,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_GRAPH_TRAITS_H
-#define LLVM_SUPPORT_GRAPH_TRAITS_H
+#ifndef SUPPORT_GRAPHTRAITS_H
+#define SUPPORT_GRAPHTRAITS_H
 
 // GraphTraits - This class should be specialized by different graph types...
 // which is why the default version is empty.


Index: llvm/include/Support/HashExtras.h
diff -u llvm/include/Support/HashExtras.h:1.5 llvm/include/Support/HashExtras.h:1.5.2.1
--- llvm/include/Support/HashExtras.h:1.5	Sun Oct 27 20:11:16 2002
+++ llvm/include/Support/HashExtras.h	Thu Jun 26 16:34:33 2003
@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_HASHEXTRAS_H
-#define LLVM_SUPPORT_HASHEXTRAS_H
+#ifndef SUPPORT_HASHEXTRAS_H
+#define SUPPORT_HASHEXTRAS_H
 
 #include <string>
 #include "Support/hash_map"


Index: llvm/include/Support/LeakDetector.h
diff -u llvm/include/Support/LeakDetector.h:1.1 llvm/include/Support/LeakDetector.h:1.1.2.1
--- llvm/include/Support/LeakDetector.h:1.1	Sun Sep  8 13:51:12 2002
+++ llvm/include/Support/LeakDetector.h	Thu Jun 26 16:34:33 2003
@@ -12,8 +12,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_LEAK_DETECTOR_H
-#define SUPPORT_LEAK_DETECTOR_H
+#ifndef SUPPORT_LEAKDETECTOR_H
+#define SUPPORT_LEAKDETECTOR_H
 
 #include <string>
 class Value;


Index: llvm/include/Support/MathExtras.h
diff -u llvm/include/Support/MathExtras.h:1.5 llvm/include/Support/MathExtras.h:1.5.2.1
--- llvm/include/Support/MathExtras.h:1.5	Sun Oct 27 20:11:16 2002
+++ llvm/include/Support/MathExtras.h	Thu Jun 26 16:34:33 2003
@@ -4,8 +4,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_MATH_EXTRAS_H
-#define SUPPORT_MATH_EXTRAS_H
+#ifndef SUPPORT_MATHEXTRAS_H
+#define SUPPORT_MATHEXTRAS_H
 
 #include "Support/DataTypes.h"
 


Index: llvm/include/Support/NonCopyable.h
diff -u llvm/include/Support/NonCopyable.h:1.2 llvm/include/Support/NonCopyable.h:1.2.2.1
--- llvm/include/Support/NonCopyable.h:1.2	Tue Jun  3 10:30:48 2003
+++ llvm/include/Support/NonCopyable.h	Thu Jun 26 16:34:33 2003
@@ -9,8 +9,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_NONCOPYABLE_H
-#define LLVM_SUPPORT_NONCOPYABLE_H
+#ifndef SUPPORT_NONCOPYABLE_H
+#define SUPPORT_NONCOPYABLE_H
 
 class NonCopyable {
   // Disable the copy constructor and the assignment operator


Index: llvm/include/Support/PostOrderIterator.h
diff -u llvm/include/Support/PostOrderIterator.h:1.8 llvm/include/Support/PostOrderIterator.h:1.8.2.1
--- llvm/include/Support/PostOrderIterator.h:1.8	Fri Mar 21 15:40:39 2003
+++ llvm/include/Support/PostOrderIterator.h	Thu Jun 26 16:34:33 2003
@@ -6,8 +6,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_POSTORDER_ITERATOR_H
-#define LLVM_SUPPORT_POSTORDER_ITERATOR_H
+#ifndef SUPPORT_POSTORDERITERATOR_H
+#define SUPPORT_POSTORDERITERATOR_H
 
 #include "Support/GraphTraits.h"
 #include "Support/iterator"


Index: llvm/include/Support/STLExtras.h
diff -u llvm/include/Support/STLExtras.h:1.5 llvm/include/Support/STLExtras.h:1.5.2.1
--- llvm/include/Support/STLExtras.h:1.5	Sun Oct 27 13:16:27 2002
+++ llvm/include/Support/STLExtras.h	Thu Jun 26 16:34:33 2003
@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_STL_EXTRAS_H
-#define LLVM_SUPPORT_STL_EXTRAS_H
+#ifndef SUPPORT_STLEXTRAS_H
+#define SUPPORT_STLEXTRAS_H
 
 #include <functional>
 #include "Support/iterator"


Index: llvm/include/Support/SetOperations.h
diff -u llvm/include/Support/SetOperations.h:1.1 llvm/include/Support/SetOperations.h:1.1.2.1
--- llvm/include/Support/SetOperations.h:1.1	Mon Feb  4 21:35:10 2002
+++ llvm/include/Support/SetOperations.h	Thu Jun 26 16:34:33 2003
@@ -5,8 +5,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_SET_OPERATIONS_H
-#define LLVM_SUPPORT_SET_OPERATIONS_H
+#ifndef SUPPORT_SETOPERATIONS_H
+#define SUPPORT_SETOPERATIONS_H
 
 // set_union(A, B) - Compute A := A u B, return whether A changed.
 //


Index: llvm/include/Support/StringExtras.h
diff -u llvm/include/Support/StringExtras.h:1.3 llvm/include/Support/StringExtras.h:1.3.2.1
--- llvm/include/Support/StringExtras.h:1.3	Sun Apr  7 03:36:19 2002
+++ llvm/include/Support/StringExtras.h	Thu Jun 26 16:34:33 2003
@@ -4,8 +4,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_STRING_EXTRAS_H
-#define SUPPORT_STRING_EXTRAS_H
+#ifndef SUPPORT_STRINGEXTRAS_H
+#define SUPPORT_STRINGEXTRAS_H
 
 #include "Support/DataTypes.h"
 #include <string>


Index: llvm/include/Support/TarjanSCCIterator.h
diff -u llvm/include/Support/TarjanSCCIterator.h:1.5.2.1 llvm/include/Support/TarjanSCCIterator.h:1.5.2.2
--- llvm/include/Support/TarjanSCCIterator.h:1.5.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/TarjanSCCIterator.h	Thu Jun 26 16:34:33 2003
@@ -1,4 +1,4 @@
-//===-- Support/TarjanSCCIterator.h -Generic Tarjan SCC iterator -*- C++ -*--=//
+//===-- Support/TarjanSCCIterator.h - Tarjan SCC iterator -------*- C++ -*-===//
 //
 // This builds on the Support/GraphTraits.h file to find the strongly 
 // connected components (SCCs) of a graph in O(N+E) time using
@@ -9,18 +9,18 @@
 // 
 // To visit S1 *before* S2, use the TarjanSCCIterator on the Inverse graph.
 // (NOTE: This requires some simple wrappers and is not supported yet.)
+//
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_TARJANSCC_ITERATOR_H
-#define LLVM_SUPPORT_TARJANSCC_ITERATOR_H
+#ifndef SUPPORT_TARJANSCCITERATOR_H
+#define SUPPORT_TARJANSCCITERATOR_H
 
 #include "Support/GraphTraits.h"
-#include <Support/Statistic.h>
-#include <Support/iterator>
+#include "Support/Statistic.h"
+#include "Support/iterator"
 #include <vector>
 #include <stack>
 #include <map>
-
 #include "Config/assert.h"
 
 //--------------------------------------------------------------------------


Index: llvm/include/Support/Timer.h
diff -u llvm/include/Support/Timer.h:1.6.2.1 llvm/include/Support/Timer.h:1.6.2.2
--- llvm/include/Support/Timer.h:1.6.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/Timer.h	Thu Jun 26 16:34:33 2003
@@ -64,7 +64,7 @@
     PeakMemBase = T.PeakMemBase;
     Name = T.Name;
     Started = T.Started;
-    assert (TG == T.TG && "Can only assign timers in the same TimerGroup!");
+    assert(TG == T.TG && "Can only assign timers in the same TimerGroup!");
     return *this;
   }
 


Index: llvm/include/Support/Tree.h
diff -u llvm/include/Support/Tree.h:1.3.2.1 llvm/include/Support/Tree.h:1.3.2.2
--- llvm/include/Support/Tree.h:1.3.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/Tree.h	Thu Jun 26 16:34:33 2003
@@ -5,11 +5,10 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_TREE_H
-#define LLVM_SUPPORT_TREE_H
+#ifndef SUPPORT_TREE_H
+#define SUPPORT_TREE_H
 
 #include <vector>
-
 #include "Config/assert.h"
 
 template<class ConcreteTreeNode, class Payload>


Index: llvm/include/Support/TypeInfo.h
diff -u llvm/include/Support/TypeInfo.h:1.1 llvm/include/Support/TypeInfo.h:1.1.2.1
--- llvm/include/Support/TypeInfo.h:1.1	Tue Jul 23 12:56:53 2002
+++ llvm/include/Support/TypeInfo.h	Thu Jun 26 16:34:33 2003
@@ -6,8 +6,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_TYPEINFO_H
-#define LLVM_SUPPORT_TYPEINFO_H
+#ifndef SUPPORT_TYPEINFO_H
+#define SUPPORT_TYPEINFO_H
 
 #include <typeinfo>
 


Index: llvm/include/Support/hash_map
diff -u llvm/include/Support/hash_map:1.6.2.1 llvm/include/Support/hash_map:1.6.2.2
--- llvm/include/Support/hash_map:1.6.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/hash_map	Thu Jun 26 16:34:33 2003
@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_HASHMAP_H
-#define SUPPORT_HASHMAP_H
+#ifndef SUPPORT_HASH_MAP
+#define SUPPORT_HASH_MAP
 
 // Compiler Support Matrix
 //


Index: llvm/include/Support/hash_set
diff -u llvm/include/Support/hash_set:1.6.2.1 llvm/include/Support/hash_set:1.6.2.2
--- llvm/include/Support/hash_set:1.6.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/hash_set	Thu Jun 26 16:34:33 2003
@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_HASHSET_H
-#define SUPPORT_HASHSET_H
+#ifndef SUPPORT_HASH_SET
+#define SUPPORT_HASH_SET
 
 // Compiler Support Matrix
 //


Index: llvm/include/Support/ilist
diff -u llvm/include/Support/ilist:1.6.2.1 llvm/include/Support/ilist:1.6.2.2
--- llvm/include/Support/ilist:1.6.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/ilist	Thu Jun 26 16:34:33 2003
@@ -28,8 +28,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef INCLUDED_SUPPORT_ILIST
-#define INCLUDED_SUPPORT_ILIST
+#ifndef SUPPORT_ILIST
+#define SUPPORT_ILIST
 
 #include "Config/assert.h"
 #include <algorithm>


Index: llvm/include/Support/iterator
diff -u llvm/include/Support/iterator:1.2.2.1 llvm/include/Support/iterator:1.2.2.2
--- llvm/include/Support/iterator:1.2.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/iterator	Thu Jun 26 16:34:33 2003
@@ -16,8 +16,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_ITERATOR_H
-#define SUPPORT_ITERATOR_H
+#ifndef SUPPORT_ITERATOR
+#define SUPPORT_ITERATOR
 
 #include "Config/config.h"
 


Index: llvm/include/Support/slist
diff -u llvm/include/Support/slist:1.2.2.1 llvm/include/Support/slist:1.2.2.2
--- llvm/include/Support/slist:1.2.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/slist	Thu Jun 26 16:34:33 2003
@@ -7,8 +7,8 @@
 //
 //===----------------------------------------------------------------------===//
 
-#ifndef SUPPORT_SLIST_H
-#define SUPPORT_SLIST_H
+#ifndef SUPPORT_SLIST
+#define SUPPORT_SLIST
 
 #include "Config/config.h"
 





More information about the llvm-commits mailing list
Index: llvm/include/Support/BitSetVector.h
diff -u llvm/include/Support/BitSetVector.h:1.5.2.1 llvm/include/Support/BitSetVector.h:1.5.2.2
--- llvm/include/Support/BitSetVector.h:1.5.2.1	Mon Jun 23 13:50:38 2003
+++ llvm/include/Support/BitSetVector.h	Thu Jun 26 16:34:32 2003
@@ -9,12 +9,6 @@
 // We therefore use a vector of bitsets.  The maxmimum size of our sets
 // (i.e., the size of the universal set) can be chosen at creation time.
 //
-// The size of each Bitset is defined by the macro WORDSIZE.
-// 
-// NOTE: The WORDSIZE macro should be made machine-dependent, in order to use
-// 64-bit words or whatever gives most efficient Bitsets on each platform.
-// 
-// 
 // External functions:
 // 
 // bool Disjoint(const BitSetVector& set1, const BitSetVector& set2):
@@ -23,22 +17,20 @@
 // 
 //===----------------------------------------------------------------------===//
 
-#ifndef LLVM_SUPPORT_BITVECTORSET_H
-#define LLVM_SUPPORT_BITVECTORSET_H
+#ifndef SUPPORT_BITSETVECTOR_H
+#define SUPPORT_BITSETVECTOR_H
 
 #include <bitset>
 #include <vector>
 #include <functional>
 #include <iostream>
-
 #include "Config/assert.h"
 
-#define WORDSIZE (32U)
-
-
 class BitSetVector {
+  enum { BITSET_WORDSIZE = sizeof(long)*8 };
+
   // Types used internal to the representation
-  typedef std::bitset<WORDSIZE> bitword;
+  typedef std::bitset<BITSET_WORDSIZE> bitword;
   typedef bitword::reference reference;
   class iterator;
 
@@ -48,11 +40,13 @@
 
 private:
   // Utility functions for the representation
-  static unsigned NumWords(unsigned Size) { return (Size+WORDSIZE-1)/WORDSIZE;} 
-  static unsigned LastWordSize(unsigned Size) { return Size % WORDSIZE; }
+  static unsigned NumWords(unsigned Size) {
+    return (Size+BITSET_WORDSIZE-1)/BITSET_WORDSIZE;
+  } 
+  static unsigned LastWordSize(unsigned Size) { return Size % BITSET_WORDSIZE; }
 
   // Clear the unused bits in the last word.
   // The unused bits are the high (WORDSIZE - LastWordSize()) bits
   void ClearUnusedBits() {
     unsigned long usedBits = (1U << LastWordSize(size())) - 1;
     bitsetVec.back() &= bitword(usedBits);
@@ -91,7 +85,7 @@
   }
   reference operator[](unsigned n) {
     assert(n  < size() && "BitSetVector: Bit number out of range");
-    unsigned ndiv = n / WORDSIZE, nmod = n % WORDSIZE;
+    unsigned ndiv = n / BITSET_WORDSIZE, nmod = n % BITSET_WORDSIZE;
     return bitsetVec[ndiv][nmod];
   }
   iterator begin() { return iterator::begin(*this); }
@@ -116,7 +110,7 @@
   ///  
   bool test(unsigned n) const {
     assert(n  < size() && "BitSetVector: Bit number out of range");
-    unsigned ndiv = n / WORDSIZE, nmod = n % WORDSIZE;
+    unsigned ndiv = n / BITSET_WORDSIZE, nmod = n % BITSET_WORDSIZE;
     return bitsetVec[ndiv].test(nmod);
   }
   bool any() const {
@@ -203,13 +197,13 @@
 
     // Increment and decrement operators (pre and post)
     iterator& operator++() {
-      if (++currentBit == WORDSIZE)
+      if (++currentBit == BITSET_WORDSIZE)
         { currentBit = 0; if (currentWord < bitvec->size()) ++currentWord; }
       return *this;
     }
     iterator& operator--() {
       if (currentBit == 0) {
-        currentBit = WORDSIZE-1;
+        currentBit = BITSET_WORDSIZE-1;
         currentWord = (currentWord == 0)? bitvec->size() : --currentWord;
       }
       else
@@ -48,11 +40,13 @@
 
   // Clear the unused bits in the last word.
-  // The unused bits are the high (WORDSIZE - LastWordSize()) bits
+  // The unused bits are the high (BITSET_WORDSIZE - LastWordSize()) bits
   void ClearUnusedBits() {
     unsigned long usedBits = (1U << LastWordSize(size())) - 1;

